pub struct AcknowledgerReference {
pub label: String,
pub html_url: Option<String>,
pub _self: Option<String>,
pub summary: Option<String>,
pub id: Option<String>,
pub _type: AcknowledgerReferenceTypeEnum,
}Fields
label: StringThe label of the tag.
html_url: Option<String>a URL at which the entity is uniquely displayed in the Web app
_self: Option<String>the API show URL at which the object is accessible
summary: Option<String>A short-form, server-generated string that provides succinct, important information about an object suitable for primary labeling of an entity in a client. In many cases, this will be identical to name, though it is not intended to be an identifier.
id: Option<String>_type: AcknowledgerReferenceTypeEnumTrait Implementations
Sourceimpl Clone for AcknowledgerReference
impl Clone for AcknowledgerReference
Sourcefn clone(&self) -> AcknowledgerReference
fn clone(&self) -> AcknowledgerReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AcknowledgerReference
impl Debug for AcknowledgerReference
Sourceimpl Default for AcknowledgerReference
impl Default for AcknowledgerReference
Sourceimpl<'de> Deserialize<'de> for AcknowledgerReference
impl<'de> Deserialize<'de> for AcknowledgerReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AcknowledgerReference
impl PartialEq for AcknowledgerReference
Sourceimpl Serialize for AcknowledgerReference
impl Serialize for AcknowledgerReference
impl StructuralPartialEq for AcknowledgerReference