pub struct Channel {
pub _type: String,
pub user: Option<HashMap<String, Value>>,
pub team: Option<HashMap<String, Value>>,
pub notification: Option<Notification>,
pub channel: Option<HashMap<String, Value>>,
}Expand description
Polymorphic object representation of the means by which the action was channeled. Has different formats depending on type, indicated by channel[type]. Will be one of auto, email, api, nagios, or timeout if agent[type] is service. Will be one of email, sms, website, web_trigger, or note if agent[type] is user. See below for detailed information about channel formats.
Fields
_type: Stringtype
user: Option<HashMap<String, Value>>team: Option<HashMap<String, Value>>notification: Option<Notification>channel: Option<HashMap<String, Value>>channel