pub struct EventRuleActions {
pub route: Option<HashMap<String, Value>>,
}Fields
route: Option<HashMap<String, Value>>Set the service ID of the target service for the resulting alert. You can find the service you want to route to by calling the services endpoint.