pub struct IntegrationReference {
pub label: String,
pub html_url: Option<String>,
pub _self: Option<String>,
pub summary: Option<String>,
pub id: Option<String>,
pub _type: IntegrationReferenceTypeEnum,
}Fields
label: StringThe label of the tag.
html_url: Option<String>a URL at which the entity is uniquely displayed in the Web app
_self: Option<String>the API show URL at which the object is accessible
summary: Option<String>A short-form, server-generated string that provides succinct, important information about an object suitable for primary labeling of an entity in a client. In many cases, this will be identical to name, though it is not intended to be an identifier.
id: Option<String>_type: IntegrationReferenceTypeEnumTrait Implementations
Sourceimpl Clone for IntegrationReference
impl Clone for IntegrationReference
Sourcefn clone(&self) -> IntegrationReference
fn clone(&self) -> IntegrationReference
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IntegrationReference
impl Debug for IntegrationReference
Sourceimpl Default for IntegrationReference
impl Default for IntegrationReference
Sourceimpl<'de> Deserialize<'de> for IntegrationReference
impl<'de> Deserialize<'de> for IntegrationReference
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for IntegrationReference
impl PartialEq for IntegrationReference
Sourceimpl Serialize for IntegrationReference
impl Serialize for IntegrationReference
impl StructuralPartialEq for IntegrationReference