pub struct MatchPredicate {
pub _type: MatchPredicateTypeEnum,
pub matcher: Option<String>,
pub part: MatchPredicatePartEnum,
pub children: Vec<MatchPredicate>,
}Fields
_type: MatchPredicateTypeEnummatcher: Option<String>Required if the type is contains, exactly or regex.
part: MatchPredicatePartEnumThe email field that will attempt to use the matcher expression. Required if the type is contains, exactly or regex.
children: Vec<MatchPredicate>Additional matchers to be run. Must be not empty if the type is all, any, or not.