pub struct RelatedIncidentMachineLearningRelationshipUserFeedback {
pub positive_feedback_count: Option<isize>,
pub negative_feedback_count: Option<isize>,
}Expand description
The feedback provided from Users to influence the machine learning algorithm for future Related Incidents.
Fields
positive_feedback_count: Option<isize>The total number of times Users agreed that the Incidents are related.
negative_feedback_count: Option<isize>The total number of times Users disagreed that the Incidents are related.