pub struct ServiceDependenciesassociateSupportingService {
pub id: Option<String>,
pub _type: String,
}Expand description
The reference to the service that supports the dependent service.
Fields
id: Option<String>_type: StringTrait Implementations
Sourceimpl Clone for ServiceDependenciesassociateSupportingService
impl Clone for ServiceDependenciesassociateSupportingService
Sourcefn clone(&self) -> ServiceDependenciesassociateSupportingService
fn clone(&self) -> ServiceDependenciesassociateSupportingService
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for ServiceDependenciesassociateSupportingService
impl<'de> Deserialize<'de> for ServiceDependenciesassociateSupportingService
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ServiceDependenciesassociateSupportingService
impl PartialEq for ServiceDependenciesassociateSupportingService
Sourcefn eq(&self, other: &ServiceDependenciesassociateSupportingService) -> bool
fn eq(&self, other: &ServiceDependenciesassociateSupportingService) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ServiceDependenciesassociateSupportingService