pub struct EmailContactMethod {
pub html_url: Option<String>,
pub _self: Option<String>,
pub summary: Option<String>,
pub id: Option<String>,
pub _type: EmailContactMethodTypeEnum,
pub label: String,
pub address: String,
pub send_short_email: Option<bool>,
}Expand description
The Email Contact Method of the User.
Fields
html_url: Option<String>a URL at which the entity is uniquely displayed in the Web app
_self: Option<String>the API show URL at which the object is accessible
summary: Option<String>A short-form, server-generated string that provides succinct, important information about an object suitable for primary labeling of an entity in a client. In many cases, this will be identical to name, though it is not intended to be an identifier.
id: Option<String>_type: EmailContactMethodTypeEnumlabel: StringThe label (e.g., "Work", "Mobile", etc.).
address: StringThe "address" to deliver to: email, phone number, etc., depending on the type.
send_short_email: Option<bool>Send an abbreviated email message instead of the standard email output. Useful for email-to-SMS gateways and email based pagers.